==> jc-1.4.0.tar.gz: jas/ExceptAttr.h <==
// public class jas.ExceptAttr

// class file dependencies
// @dep_class 6cc36363fe998213 jas_ExceptAttr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_ExceptAttr_H_
#define _JC_jas_ExceptAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_ExceptAttr$sub_refs	_jc_jas_ExceptAttr$sub_refs;
typedef struct _jc_jas_ExceptAttr$sub_nonrefs	_jc_jas_ExceptAttr$sub_nonrefs;
typedef struct _jc_jas_ExceptAttr$refs	_jc_jas_ExceptAttr$refs;
typedef struct _jc_jas_ExceptAttr$nonrefs	_jc_jas_ExceptAttr$nonrefs;
typedef struct _jc_jas_ExceptAttr$object	_jc_jas_ExceptAttr$object;

typedef struct _jc_jas_ExceptAttr$fields_struct	_jc_jas_ExceptAttr$fields_struct;
typedef const struct _jc_jas_ExceptAttr$vmethods	_jc_jas_ExceptAttr$vmethods;
typedef const struct _jc_jas_ExceptAttr$vtable	_jc_jas_ExceptAttr$vtable;
typedef const struct _jc_jas_ExceptAttr$vtype	_jc_jas_ExceptAttr$vtype;

// Class fields structure
struct _jc_jas_ExceptAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_ExceptAttr$fields_struct _jc_jas_ExceptAttr$class_fields;

// Constructors
extern void _jc_jas_ExceptAttr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_ExceptAttr$object *);

// Virtual methods
extern void _jc_jas_ExceptAttr$method$addException$e60a023f01baee72(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_CP$object *);
extern void _jc_jas_ExceptAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_ExceptAttr$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_ExceptAttr$method_info$addException$e60a023f01baee72;
extern _jc_method _jc_jas_ExceptAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_ExceptAttr$method_info$write$c5719140f8114b75;

// Static methods
extern void _jc_jas_ExceptAttr$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_jas_ExceptAttr$vmethods {
	void	(*addException$e60a023f01baee72)(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_CP$object *);
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_ExceptAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_ExceptAttr$vmethods	jas_ExceptAttr;
};

// Vtype
struct _jc_jas_ExceptAttr$vtype {
	_jc_type			type;
	_jc_jas_ExceptAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_ExceptAttr$sub_refs {
	struct _jc_java_util_Vector$object	*cps;
};

// Reference instance fields (object)
struct _jc_jas_ExceptAttr$refs {
    _jc_jas_ExceptAttr$sub_refs	jas_ExceptAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_ExceptAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_ExceptAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_ExceptAttr$sub_nonrefs	jas_ExceptAttr;
};

// Object instance structure
struct _jc_jas_ExceptAttr$object {
	_jc_jas_ExceptAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_ExceptAttr$vtype	*vtype;
	_jc_jas_ExceptAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_ExceptAttr$vtype _jc_jas_ExceptAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_ExceptAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_ExceptAttr$class_object;

#endif	/* _JC_jas_ExceptAttr_H_ */

==> jc-1.4.6.tar.gz: jas/ExceptAttr.h <==
// public class jas.ExceptAttr

// class file dependencies
// @dep_class 6cc36363fe998213 jas_ExceptAttr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_ExceptAttr_H_
#define _JC_jas_ExceptAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_ExceptAttr$sub_refs	_jc_jas_ExceptAttr$sub_refs;
typedef struct _jc_jas_ExceptAttr$sub_nonrefs	_jc_jas_ExceptAttr$sub_nonrefs;
typedef struct _jc_jas_ExceptAttr$refs	_jc_jas_ExceptAttr$refs;
typedef struct _jc_jas_ExceptAttr$nonrefs	_jc_jas_ExceptAttr$nonrefs;
typedef struct _jc_jas_ExceptAttr$object	_jc_jas_ExceptAttr$object;

typedef struct _jc_jas_ExceptAttr$fields_struct	_jc_jas_ExceptAttr$fields_struct;
typedef const struct _jc_jas_ExceptAttr$vmethods	_jc_jas_ExceptAttr$vmethods;
typedef const struct _jc_jas_ExceptAttr$vtable	_jc_jas_ExceptAttr$vtable;
typedef const struct _jc_jas_ExceptAttr$vtype	_jc_jas_ExceptAttr$vtype;

// Class fields structure
struct _jc_jas_ExceptAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_ExceptAttr$fields_struct _jc_jas_ExceptAttr$class_fields;

// Constructors
extern void _jc_jas_ExceptAttr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_ExceptAttr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_ExceptAttr$method$addException$e60a023f01baee72(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;
extern void _jc_jas_ExceptAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_ExceptAttr$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_ExceptAttr$method_info$addException$e60a023f01baee72;
extern _jc_method _jc_jas_ExceptAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_ExceptAttr$method_info$write$c5719140f8114b75;

// Static methods
extern void _jc_jas_ExceptAttr$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_ExceptAttr$vmethods {
	void	(*addException$e60a023f01baee72)(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_ExceptAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_ExceptAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_ExceptAttr$vmethods	jas_ExceptAttr;
};

// Vtype
struct _jc_jas_ExceptAttr$vtype {
	_jc_type			type;
	_jc_jas_ExceptAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_ExceptAttr$sub_refs {
	struct _jc_java_util_Vector$object	*cps;
};

// Reference instance fields (object)
struct _jc_jas_ExceptAttr$refs {
    _jc_jas_ExceptAttr$sub_refs	jas_ExceptAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_ExceptAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_ExceptAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_ExceptAttr$sub_nonrefs	jas_ExceptAttr;
};

// Object instance structure
struct _jc_jas_ExceptAttr$object {
	_jc_jas_ExceptAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_ExceptAttr$vtype	*vtype;
	_jc_jas_ExceptAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_ExceptAttr$vtype _jc_jas_ExceptAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_ExceptAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_ExceptAttr$class_object;

#endif	/* _JC_jas_ExceptAttr_H_ */
